#
# spec file for package ghc-streaming-commons
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name streaming-commons
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.2.2.6
Release:        2.17
Summary:        Common lower-level functions needed by various streaming data libraries
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-array-prof
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-async-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-prof
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-random-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-stm-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unix-prof
BuildRequires:  ghc-zlib-devel
BuildRequires:  ghc-zlib-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
%endif

%description
Provides low-dependency functionality commonly needed by various streaming data
libraries, such as conduit and pipes.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Wed Oct 11 2023 Peter Simons <psimons@suse.com>
- Update streaming-commons to version 0.2.2.6 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Apr  3 2023 Peter Simons <psimons@suse.com>
- Update streaming-commons to version 0.2.2.6.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/streaming-commons-0.2.2.6/src/ChangeLog.md
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Oct 23 2022 Peter Simons <psimons@suse.com>
- Update streaming-commons to version 0.2.2.5.
  [#]# 0.2.2.5
  * UTF-8 Decoder fails on trailing bytes [#71](https://github.com/fpco/streaming-commons/pull/71)
* Sun Feb  6 2022 Peter Simons <psimons@suse.com>
- Update streaming-commons to version 0.2.2.4.
  [#]# 0.2.2.4
  * Fix docstrings for text 2.0
  [#]# 0.2.2.3
  * Support text 2.0 [#65](https://github.com/fpco/streaming-commons/pull/65)
* Wed Nov 10 2021 psimons@suse.com
- Update streaming-commons to version 0.2.2.2.
  [#]# 0.2.2.2
  * Support GHC 9.2 [#62](https://github.com/fpco/streaming-commons/pull/62)
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jul 21 2020 psimons@suse.com
- Update streaming-commons to version 0.2.2.1.
  [#]# 0.2.2.1
  * Fix test suite compilation issue [stackage#5528](https://github.com/commercialhaskell/stackage/issues/5528)
* Mon Jul 20 2020 psimons@suse.com
- Update streaming-commons to version 0.2.2.0.
  [#]# 0.2.2.0
  * Remove `AI_ADDRCONFIG` [#58](https://github.com/fpco/streaming-commons/issues/58)
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Mon Jan  6 2020 psimons@suse.com
- Update streaming-commons to version 0.2.1.2.
  [#]# 0.2.1.2
  * Update `defaultReadBufferSize` to use system default instead of hardcoded value [#54](https://github.com/fpco/streaming-commons/issues/54)
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Thu Jun  6 2019 psimons@suse.com
- Update streaming-commons to version 0.2.1.1.
  [#] ChangeLog for streaming-commons
  [#]# 0.2.1.1
  * Fix a failing test case (invalid `ByteString` copying), does not affect library itself
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update streaming-commons to version 0.2.1.0.
  [#]# 0.2.1.0
  * Change `bindRandomPortGen` to use binding to port 0
* Mon May 14 2018 psimons@suse.com
- Update streaming-commons to version 0.2.0.0.
  * Drop `blaze-builder` dependency
  * Update `getAddrInfo` hints to allow hostnames and portnames [#46](https://github.com/fpco/streaming-commons/issues/46)
  * Add `isCompleteInflate`
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jan 26 2017 psimons@suse.com
- Update to version 0.1.17 with cabal2obs.
* Mon Sep 26 2016 psimons@suse.com
- Update to version 0.1.16 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.1.15.5 revision 0 with cabal2obs.
* Thu May 12 2016 mimi.vx@gmail.com
- update to 0.1.15.5
  * Make getSocket{Family}TCP try all addr candidates
* Tue Apr 26 2016 mimi.vx@gmail.com
- update to 0.1.15.4
  * Fix benchmarks
* Tue Mar  8 2016 mimi.vx@gmail.com
- update to 0.1.15.2
  * Document child process behavior in waitForProcess
* Thu Feb 11 2016 mimi.vx@gmail.com
- update to 0.1.15.1
  * Catch exceptions thrown by waitForProcess
* Sun Nov 29 2015 mimi.vx@gmail.com
- update to 0.1.15
  * Use `NO_DELAY1 for TCP client connections
* Sun Oct  4 2015 mimi.vx@gmail.com
- update to 0.1.14.2
  * Fix bug in process exception display of args with spaces/quotes
* Sun Sep 27 2015 mimi.vx@gmail.com
- update to 0.1.14.1
  * Exporting HasReadBufferSize; instance for ClientSettingsUnix
* Sun Sep 13 2015 mimi.vx@gmail.com
- update to 0.1.13
  * Make size of read buffer configurable, change default size to 32 kiB
* Fri Aug  7 2015 mimi.vx@gmail.com
- update to 0.1.12.1
  * Fix up acceptSafe
* Wed Apr 22 2015 mimi.vx@gmail.com
- initial commit
